==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/cs.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Heslo musí být alespoň %s znaků dlouhé",
    "Password needs to contain at least one lower and one upper case character." : "Heslo musí obsahovat alespoň jedno malé a jedno velké písmeno.",
    "Password needs to contain at least one numeric character." : "Heslo musí obsahovat alespoň jedno číslo.",
    "Password needs to contain at least one special character." : "Heslo musí obsahovat alespoň jeden speciální znak.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Heslo spadá mezi 1,000,000 nejběžnějších hesel. Vyberte si prosím jiné.",
    "Password policy" : "Požadavky pro hesla",
    "Minimal length" : "Minimální délka",
    "Forbid common passwords" : "Zakázat běžná hesla",
    "Enforce upper and lower case characters" : "Vyžadovat VELKÉ a malé znaky",
    "Enforce numeric characters" : "Vyžadovat čísla",
    "Enforce special characters" : "Vyžadovat speciální znaky",
    "Password need to be at least %s characters long" : "Heslo musí být alespoň %s znaků dlouhé",
    "Password need to contain at least one lower case character and one upper case character." : "Heslo musí obsahovat alespoň jedno malé a jedno velké písmeno.",
    "Password need to contain at least one numeric character." : "Heslo musí obsahovat alespoň jedno číslo.",
    "Password need to contain at least one special character." : "Heslo musí obsahovat alespoň jeden speciální znak.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Heslo spadá mezi 1,000,000 nejběžnějších hesel. Vyberte si prosím jiné."
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/cs.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Heslo musí být alespoň %s znaků dlouhé",
    "Password needs to contain at least one lower and one upper case character." : "Heslo musí obsahovat alespoň jedno malé a jedno velké písmeno.",
    "Password needs to contain at least one numeric character." : "Je třeba, aby heslo obsahovalo alespoň jedno číslo.",
    "Password needs to contain at least one special character." : "Heslo musí obsahovat alespoň jeden speciální znak.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Heslo spadá mezi 1,000,000 nejběžnějších hesel. Vyberte si prosím jiné.",
    "Password is present in compromised password list. Please choose a different password." : "Heslo se nachází na seznamu kompromitovaných hesel. Zvolte jiné.",
    "Password policy" : "Požadavky pro hesla",
    "Allows admins to configure a password policy" : "Umožňuje správcům nastavovat pravidla pro hesla",
    "Minimal length" : "Minimální délka",
    "Forbid common passwords" : "Zakázat běžná hesla",
    "Enforce upper and lower case characters" : "Vyžadovat VELKÁ a malá písmena",
    "Enforce numeric characters" : "Vyžadovat čísla",
    "Enforce special characters" : "Vyžadovat speciální znaky",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Zkontrolovat heslo vůči seznamu prolomených hesel na haveibeenpwned.com",
    "Password need to be at least %s characters long" : "Je třeba, aby heslo bylo alespoň %s znaků dlouhé",
    "Password need to contain at least one lower case character and one upper case character." : "Heslo musí obsahovat alespoň jedno malé a jedno velké písmeno.",
    "Password need to contain at least one numeric character." : "Heslo musí obsahovat alespoň jedno číslo.",
    "Password need to contain at least one special character." : "Heslo musí obsahovat alespoň jeden speciální znak.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Heslo spadá mezi 1,000,000 nejběžnějších hesel. Vyberte si prosím jiné."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
